#include "Adafruit_GFX.h"
#include "glcdfont.c"
#include <avr/pgmspace.h>
#include <stdlib.h>
#include <util/delay.h>
#include "uart.h"
#include "TouchScreen.h"
#include "Programs.h"

 //Screen parameters
 #define BOXSIZE 40
 #define MINPRESSURE 200
 #define MAXPRESSURE 1000
 #define PENRADIUS 4
 #define TS_MINX 150
 #define TS_MINY 120
 #define TS_MAXX 920
 #define TS_MAXY 940

 //General colors
 #define	BLACK           0x0000
 #define 	WHITE           0xFFFF
 #define	RED             0xF800
 #define 	YELLOW          0xFFE0 
 #define	GREEN           0x07E0
 #define 	CYAN            0x07FF
 #define	BLUE            0x001F
 #define 	MAGENTA         0xF81F
 #define	GREY			50712
 #define    ORANGE			64800
 #define	PINK			63733
 #define	BROWN			35362

 //UART definition
 FILE uart_str = FDEV_SETUP_STREAM(uart_putchar, uart_getchar, _FDEV_SETUP_RW);

void drawMenu(void)
{
	//Clear Screen
	fillScreen(BLACK);
	//Draw Text on screen
  	setTextColor(WHITE);
  	setCursor(15,0);
  	setTextSize(4);
  	drawString("MAIN MENU\n");
  	setCursor(45,35);
  	setTextSize(2);
  	drawString("Select a game\n");
  	setCursor(70,55);
  	drawString("to begin!\n");
  	setCursor(40,280);
  	setTextSize(1);
  	drawString("Touch the top of the screen\n");
  	setCursor(42,300);
  	drawString("to come back to this menu\n");
	//Draw Buttons on Screen
  	fillRect(50, 90, BOXSIZE+100, BOXSIZE, GREY);
  	fillRect(50, 90+BOXSIZE+10, BOXSIZE+100, BOXSIZE, GREY);
  	fillRect(50, 90+BOXSIZE*2+20, BOXSIZE+100, BOXSIZE, GREY);
	//Draw Text on buttons
  	setTextSize(2);
  	setTextColor(BLACK);
  	setCursor(65,102);
  	drawString("Free Draw\n");
  	setCursor(55,102+BOXSIZE+10);
  	drawString("Tic-Tac-Toe\n");
  	setCursor(80,102+BOXSIZE*2+20);
  	drawString("Yellow\n");
}

int main(void)
 {
 	//Touch Variables
    int x;
	int y;
	uint16_t z;
	//Initalize the serial communication
	uart_init();
	stdout = stdin = stderr = &uart_str;
	fprintf(stdout,"Program is running!\n\r");
	//Initialize the LCD
	Adafruit_TFTLCD(0, 1, 2, 3, 4);
	//Reset the LCD
	reset();
	//Identify the LCD controller
	uint16_t identifier = readRegister(0x0);
	if (identifier == 0x9325) {
    	fprintf(stdout,"Found ILI9325\n\r");
		fprintf(stdout,"%x\n\r",identifier);
    } 
	else if (identifier == 0x9328) {
    	fprintf(stdout,"Found ILI9328\n\r");
    } 
	else if (identifier == 0x7575) {
    	fprintf(stdout,"Found HX8347G\n\r");
  	} 
	else {
    	fprintf(stdout,"Unknown driver chip\n\r");
    	fprintf(stdout,"%x\n\r",identifier);
    	while (1);
  }  
  //Setup the LCD
  begin(identifier);
  //Start the ADC
  ADCSRA = (1<<ADEN) | (1<<ADSC) + 7 ;
  //Draw the main menu
  drawMenu();
  while(1)
  {
  	//Read in x position, y position and pressure
	z=pressure();
	x= readTouchX();
	y=readTouchY();
	//Convert raw x and y positions to screen positions
	x=map(x,TS_MINX, TS_MAXX, TFTWIDTH, 0);
	y=map(y,TS_MINY, TS_MAXY, TFTHEIGHT, 0);
	//If pressure is between threshold, valid touch occured
	if(z>250 && z<750)
	{
		if(x>50 && x<(150+BOXSIZE))
		{
			//If top button is pressed, start free draw
			if (y>90 && y<(90+BOXSIZE))
			{
				free_draw();
				//redraw menu when free draw exits
				drawMenu();
			}
			//If middle button is pressed, start Tic-Tac-Toe
			else if (y>(90+BOXSIZE+10) && y<(90+BOXSIZE+10+BOXSIZE))
			{
				tictactoe();
				//redraw menu when Tic-Tac-Toe exits
				drawMenu();
					
			}
			//If bottom button is pressed, start Pac-Man
			else if (y>(90+BOXSIZE*2+20) && y<(90+BOXSIZE*3+20))
			{
				pac_man();
				//redraw menu when Pac-Man exits
				drawMenu();
			}
		}
	}
  }
}
