// Touch screen library with X Y and Z (pressure) readings as well
// as oversampling to avoid 'bouncing'
// (c) ladyada / adafruit
// Code under MIT License

#include <avr/pgmspace.h>
#include <avr/io.h>
#include "TouchScreen.h"
#include <util/delay.h>


void TouchScreen(uint8_t xp, uint8_t yp, uint8_t xm, uint8_t ym) {
  _yp = yp;
  _xm = xm;
  _ym = ym;
  _xp = xp;
  _rxplate = 0;
  pressureThreshhold = 10;
}


//Y+ is pin A0
//X- is pin A1
//X+ is pin A2
//Y- is pin A3

int readTouchX(void) {
   int x_val=0;
   DDRA &= ~((1<<PINA0) | (1<<PINA3)); //Set Y+ and Y- to inputs
   PORTA &= ~((1<<PINA0) | (1<<PINA3) | (1<<PINA1)); //Set Y+,Y-,X- to ground
   
   DDRA |= ((1<<PINA1) | (1<<PINA2)); //Set X+ and X- to outputs 
   PORTA |= (1<<PINA2);	//Set X+ high
   ADMUX = (1<<REFS0); //Read value of Y+
   ADCSRA |= (1<<ADSC) ;
   _delay_us(200);
   x_val = ADCL;	//Read high first
   x_val = x_val + (ADCH<<8); //Then read low
   
   x_val = 1023-x_val;
   return x_val; //Return raw X position
}



//Y+ is pin A0
//X- is pin A1
//X+ is pin A2
//Y- is pin A3


int readTouchY(void) {
   int y_val;
   DDRA &= ~((1<<PINA1) | (1<<PINA2)); //Sets X+ and X- to inputs
   PORTA &= ~((1<<PINA1) | (1<<PINA2) | (1<<PINA3)); //Sets X+,X- and Y- to ground
   
   DDRA |= (1<<PINA0) | (1<<PINA3); //Sets Y+ and Y- as outputs
   PORTA |= (1<<PINA0); //Sets Y+ high

   ADMUX = (1<<REFS0) + 1; //Read X-
   ADCSRA |= (1<<ADSC);
   _delay_us(200);
   y_val = ADCL; //Read high first
   y_val = y_val + (ADCH<<8); //Then read low
   
   y_val = 1023-y_val;
   return y_val; //Returns raw Y position
}

//Y+ is pin A0
//X- is pin A1
//X+ is pin A2
//Y- is pin A3


uint16_t pressure(void) {
  // Set X+ output to ground
  DDRA |= (1<<PINA2);
  PORTA &= ~(1<<PINA2);
  
  // Set Y- output to VCC
  DDRA |= (1<<PINA3);
  PORTA |= (1<<PINA3); 
  
  // Set X- and Y+ as inputs and to ground
  DDRA &= ~((1<<PINA0) | (1<<PINA1));
  PORTA &= ~((1<<PINA0) | (1<<PINA1));
  
  ADMUX = (1<<REFS0) + 1; //Read the value of X-
  ADCSRA |= (1<<ADSC);
  _delay_us(200);
  int z1 = ADCL;	//Read the high
  z1 = z1 + (ADCH<<8); //Read the low
  ADMUX = (1<<REFS0); //Read the value of Y+
  ADCSRA |= (1<<ADSC);
  _delay_us(200);
  int z2 = ADCL; //Read the high
  z2 = z2 + (ADCH<<8); //Read the low

    // now read the x 
    float rtouch;
    rtouch = z2;
    rtouch /= z1;
    rtouch -= 1;
    rtouch *= readTouchX();
    rtouch *= 330;
    rtouch /= 1024;
    
    return rtouch; //Return the pressure value
}
