#include "Adafruit_GFX.h"
#include "glcdfont.c"
#include <avr/pgmspace.h>
#include <stdlib.h>
#include <util/delay.h>
#include "uart.h"
#include "TouchScreen.h"
#include "Programs.h"

 //Screen parameters
 #define BOXSIZE 40
 #define MINPRESSURE 200
 #define MAXPRESSURE 1000
 #define PENRADIUS 4
 #define TS_MINX 150
 #define TS_MINY 120
 #define TS_MAXX 920
 #define TS_MAXY 940

  //General colors
 #define	BLACK           0x0000
 #define 	WHITE           0xFFFF
 #define	RED             0xF800
 #define 	YELLOW          0xFFE0 
 #define	GREEN           0x07E0
 #define 	CYAN            0x07FF
 #define	BLUE            0x001F
 #define 	MAGENTA         0xF81F
 #define	GREY			50712
 #define    ORANGE			64800
 #define	PINK			63733
 #define	BROWN			35362

void pac_man()
{
	//Touch Variables
    int x;
	int y;
	int yy;
	uint16_t z;
	//Pac-man variables
	int step=0;
	int pac_x;
	int pac_y;
	int dir=0;  //Left=0, Up=1, Right=2, Down=3
	int control=0;
	int old_x=0;
	int old_y=0;
	int new_x=0;
	int new_y=0;
	int diff_x=0;
	int diff_y=0;
	int ani_step=0;
	//Clear screen
	fillScreen(BLACK);
	setTextColor(WHITE);
  	setCursor(67,0);
  	setTextSize(3);
	//Draw title text
  	drawString("Yellow\n");
	//Set pac-man's starting position
	pac_x=50;
	pac_y=50;

	//Top Horizontal Lines
	drawLine(0,35,240,35,BLUE);
	drawLine(0,36,240,36,BLUE);
	drawLine(29,64,209,64,BLUE);
	drawLine(30,65,210,65,BLUE);

	//Left Verticle Lines
	drawLine(0,35,0,160,BLUE);
	drawLine(1,36,1,160,BLUE);
	drawLine(0,190,0,320,BLUE);
	drawLine(1,190,1,320,BLUE);
	drawLine(29,65,29,160,BLUE);
	drawLine(30,65,30,160,BLUE);
	drawLine(29,190,29,290,BLUE);
	drawLine(30,190,30,290,BLUE);
	//Right Verticle Lines
	drawLine(209,65,209,160,BLUE);
	drawLine(210,65,210,160,BLUE);
	drawLine(209,190,209,290,BLUE);
	drawLine(210,190,210,290,BLUE);
	drawLine(238,35,238,160,BLUE);
	drawLine(239,35,239,160,BLUE);
	drawLine(238,190,238,320,BLUE);
	drawLine(239,190,239,320,BLUE);
	//Botton Horizontal Lines
	drawLine(29,289,210,289,BLUE);
	drawLine(29,290,210,290,BLUE);
	drawLine(0,319,240,319,BLUE);
	drawLine(0,320,240,320,BLUE);
	//Lines Across Middle
	drawLine(29,159,60,159,BLUE);
	drawLine(29,160,60,160,BLUE);
	drawLine(90,159,150,159,BLUE);
	drawLine(90,160,150,160,BLUE);
	drawLine(180,159,210,159,BLUE);
	drawLine(180,160,210,160,BLUE);
	drawLine(29,190,60,190,BLUE);
	drawLine(29,191,60,191,BLUE);
	drawLine(90,190,150,190,BLUE);
	drawLine(90,191,150,191,BLUE);
	drawLine(180,190,210,190,BLUE);
	drawLine(180,191,210,191,BLUE);

	//Lines for top middle
	drawLine(59,160,59,100,BLUE);
	drawLine(60,160,60,100,BLUE);
	drawLine(90,160,90,130,BLUE);
	drawLine(91,160,91,130,BLUE);
	//
	drawLine(149,160,149,130,BLUE);
	drawLine(150,160,150,130,BLUE);
	drawLine(180,160,180,100,BLUE);
	drawLine(181,160,181,100,BLUE);
	drawLine(59,100,181,100,BLUE);
	drawLine(59,99,181,99,BLUE);
	//
	drawLine(90,130,150,130,BLUE);
	drawLine(90,131,150,131,BLUE);
					
	//Lines for bottom middle
	drawLine(59,191,59,251,BLUE);
	drawLine(60,191,60,251,BLUE);
	drawLine(90,191,90,221,BLUE);
	drawLine(91,191,91,221,BLUE);
	//
	drawLine(149,191,149,221,BLUE);
	drawLine(150,191,150,221,BLUE);
	drawLine(180,191,180,251,BLUE);
	drawLine(181,191,181,251,BLUE);

	drawLine(59,251,181,251,BLUE);
	drawLine(59,252,181,252,BLUE);

	drawLine(90,221,150,221,BLUE);
	drawLine(90,220,150,220,BLUE);

	//Dots on top left of screen
	fillCircle(5,10,3,YELLOW);
	fillCircle(15,10,3,YELLOW);
	fillCircle(25,10,3,YELLOW);

	//Dots horizontal middle
	fillCircle(37,175,3,YELLOW);
	fillCircle(60,175,3,YELLOW);
	fillCircle(83,175,3,YELLOW);
	fillCircle(106,175,3,YELLOW);
	fillCircle(129,175,3,YELLOW);
	fillCircle(152,175,3,YELLOW);
	fillCircle(175,175,3,YELLOW);
	fillCircle(198,175,3,YELLOW);
	
	//Dots left verticle middle
	fillCircle(75,113,5,YELLOW);
	fillCircle(75,134,3,YELLOW);
	fillCircle(75,155,3,YELLOW);
	fillCircle(75,195,3,YELLOW);
	fillCircle(75,216,3,YELLOW);
	fillCircle(75,237,5,YELLOW);

	//Dots right verticle middle
	fillCircle(165,113,5,YELLOW);
	fillCircle(165,134,3,YELLOW);
	fillCircle(165,155,3,YELLOW);
	fillCircle(165,195,3,YELLOW);
	fillCircle(165,216,3,YELLOW);
	fillCircle(165,237,5,YELLOW);

	//Dots top horizontal middle
	fillCircle(98,113,3,YELLOW);
	fillCircle(121,113,3,YELLOW);
	fillCircle(144,113,3,YELLOW);

	//Dots bottom horizontal middle
	fillCircle(98,237,3,YELLOW);
	fillCircle(121,237,3,YELLOW);
	fillCircle(144,237,3,YELLOW);

	//Top horizontal dots
	fillCircle(17,50,5,YELLOW);
	//fillCircle(40,50,3,YELLOW);
	fillCircle(63,50,3,YELLOW);
	fillCircle(86,50,3,YELLOW);
	fillCircle(109,50,3,YELLOW);
	fillCircle(131,50,3,YELLOW);
	fillCircle(154,50,3,YELLOW);
	fillCircle(177,50,3,YELLOW);
	fillCircle(200,50,3,YELLOW);
	fillCircle(224,50,5,YELLOW);
	//Botton horizontal dots
	fillCircle(17,303,5,YELLOW);
	fillCircle(40,303,3,YELLOW);
	fillCircle(63,303,3,YELLOW);
	fillCircle(86,303,3,YELLOW);
	fillCircle(109,303,3,YELLOW);
	fillCircle(131,303,3,YELLOW);
	fillCircle(154,303,3,YELLOW);
	fillCircle(177,303,3,YELLOW);
	fillCircle(200,303,3,YELLOW);
	fillCircle(224,303,5,YELLOW);
	//Right Verticle dots
	fillCircle(224,73,3,YELLOW);
	fillCircle(224,96,3,YELLOW);
	fillCircle(224,119,3,YELLOW);
	fillCircle(224,142,3,YELLOW);
	fillCircle(224,165,3,YELLOW);
	fillCircle(224,188,3,YELLOW);
	fillCircle(224,211,3,YELLOW);
	fillCircle(224,234,3,YELLOW);
	fillCircle(224,257,3,YELLOW);
	fillCircle(224,280,3,YELLOW);
	//Left Verticle dots
	fillCircle(17,73,3,YELLOW);
	fillCircle(17,96,3,YELLOW);
	fillCircle(17,119,3,YELLOW);
	fillCircle(17,142,3,YELLOW);
	fillCircle(17,165,3,YELLOW);
	fillCircle(17,188,3,YELLOW);
	fillCircle(17,211,3,YELLOW);
	fillCircle(17,234,3,YELLOW);
	fillCircle(17,257,3,YELLOW);
	fillCircle(17,280,3,YELLOW);

	//Top Ghost
	fillTopHalfCircle(197,10,10,RED);
	fillRect(187,11,21,7,RED);
	fillRect(187,18,21,4,BLACK);
	fillCircle(190,17,3,RED);
	fillCircle(197,17,3,RED);
	fillCircle(204,17,3,RED);
	fillCircle(193,9,2,WHITE);
	fillCircle(194,10,1,BLUE);
	fillCircle(201,9,2,WHITE);
	fillCircle(202,10,1,BLUE);

	//Middle Ghosts Top
	fillTopHalfCircle(180,80,10,CYAN);
	fillRect(170,81,21,7,CYAN);
	fillRect(170,88,21,4,BLACK);
	fillCircle(173,87,3,CYAN);
	fillCircle(180,87,3,CYAN);
	fillCircle(187,87,3,CYAN);
	fillCircle(176,79,2,WHITE);
	fillCircle(175,80,1,BLUE);
	fillCircle(184,79,2,WHITE);
	fillCircle(183,80,1,BLUE);
	//
	fillTopHalfCircle(150,80,10,PINK);
	fillRect(140,81,21,7,PINK);
	fillRect(140,88,21,4,BLACK);
	fillCircle(143,87,3,PINK);
	fillCircle(150,87,3,PINK);
	fillCircle(157,87,3,PINK);
	fillCircle(146,79,2,WHITE);
	fillCircle(147,80,1,BLUE);
	fillCircle(154,79,2,WHITE);
	fillCircle(155,80,1,BLUE);
	//
	fillTopHalfCircle(120,80,10,ORANGE);
	fillRect(110,81,21,7,ORANGE);
	fillRect(110,88,21,4,BLACK);
	fillCircle(113,87,3,ORANGE);
	fillCircle(120,87,3,ORANGE);
	fillCircle(127,87,3,ORANGE);
	fillCircle(116,79,2,WHITE);
	fillCircle(115,80,1,BLUE);
	fillCircle(124,79,2,WHITE);
	fillCircle(123,80,1,BLUE);
	//
	fillTopHalfCircle(90,80,10,RED);
	fillRect(80,81,21,7,RED);
	fillRect(80,88,21,4,BLACK);
	fillCircle(83,87,3,RED);
	fillCircle(90,87,3,RED);
	fillCircle(97,87,3,RED);
	fillCircle(86,79,2,WHITE);
	fillCircle(87,80,1,BLUE);
	fillCircle(94,79,2,WHITE);
	fillCircle(95,80,1,BLUE);
	//
	fillTopHalfCircle(60,80,10,CYAN);
	fillRect(50,81,21,7,CYAN);
	fillRect(50,88,21,4,BLACK);
	fillCircle(53,87,3,CYAN);
	fillCircle(60,87,3,CYAN);
	fillCircle(67,87,3,CYAN);
	fillCircle(56,79,2,WHITE);
	fillCircle(55,80,1,BLUE);
	fillCircle(64,79,2,WHITE);
	fillCircle(63,80,1,BLUE);

	//Middle Ghosts Bottom
	fillTopHalfCircle(180,267,10,PINK);
	fillRect(170,268,21,7,PINK);
	fillRect(170,275,21,4,BLACK);
	fillCircle(173,274,3,PINK);
	fillCircle(180,274,3,PINK);
	fillCircle(187,274,3,PINK);
	fillCircle(176,266,2,WHITE);
	fillCircle(177,267,1,BLUE);
	fillCircle(184,266,2,WHITE);
	fillCircle(185,267,1,BLUE);
	//
	fillTopHalfCircle(150,267,10,ORANGE);
	fillRect(140,268,21,7,ORANGE);
	fillRect(140,275,21,4,BLACK);
	fillCircle(143,274,3,ORANGE);
	fillCircle(150,274,3,ORANGE);
	fillCircle(157,274,3,ORANGE);
	fillCircle(146,266,2,WHITE);
	fillCircle(145,267,1,BLUE);
	fillCircle(154,266,2,WHITE);
	fillCircle(153,267,1,BLUE);
	//
	fillTopHalfCircle(120,267,10,RED);
	fillRect(110,268,21,7,RED);
	fillRect(110,275,21,4,BLACK);
	fillCircle(113,274,3,RED);
	fillCircle(120,274,3,RED);
	fillCircle(127,274,3,RED);
	fillCircle(116,266,2,WHITE);
	fillCircle(117,267,1,BLUE);
	fillCircle(124,266,2,WHITE);
	fillCircle(125,267,1,BLUE);
	//
	fillTopHalfCircle(90,267,10,CYAN);
	fillRect(80,268,21,7,CYAN);
	fillRect(80,275,21,4,BLACK);
	fillCircle(83,274,3,CYAN);
	fillCircle(90,274,3,CYAN);
	fillCircle(97,274,3,CYAN);
	fillCircle(86,266,2,WHITE);
	fillCircle(85,267,1,BLUE);
	fillCircle(94,266,2,WHITE);
	fillCircle(93,267,1,BLUE);
	//
	fillTopHalfCircle(60,267,10,PINK);
	fillRect(50,268,21,7,PINK);
	fillRect(50,275,21,4,BLACK);
	fillCircle(53,274,3,PINK);
	fillCircle(60,274,3,PINK);
	fillCircle(67,274,3,PINK);
	fillCircle(56,266,2,WHITE);
	fillCircle(57,267,1,BLUE);
	fillCircle(64,266,2,WHITE);
	fillCircle(65,267,1,BLUE);
	//Cherry
	fillCircle(119,147,4,RED);
	drawCircle(119,147,4,BLACK);
	drawPixel(117,147,WHITE);
	drawPixel(118,148,WHITE);
	fillCircle(123,150,4,RED);
	drawCircle(123,150,4,BLACK);
	drawPixel(121,150,WHITE);
	drawPixel(122,151,WHITE);
	//Left Stem
	drawPixel(120,144,BROWN);
	drawPixel(121,143,BROWN);
	drawPixel(122,142,BROWN);
	drawPixel(123,141,BROWN);
	drawPixel(124,141,BROWN);
	drawPixel(125,140,BROWN);
	drawPixel(126,140,BROWN);
	drawPixel(127,139,BROWN);
	//Right Stem
	drawPixel(124,147,BROWN);
	drawPixel(124,146,BROWN);
	drawPixel(124,145,BROWN);
	drawPixel(125,144,BROWN);
	drawPixel(125,143,BROWN);
	drawPixel(126,142,BROWN);
	drawPixel(126,141,BROWN);
	drawPixel(127,140,BROWN);
	drawPixel(127,139,BROWN);
	drawPixel(128,139,BROWN);
	drawPixel(129,139,BROWN);

	//Strawberry
	fillCircle(118,204,3,RED);
	fillCircle(122,204,3,RED);
	fillCircle(120,206,4,RED);
	drawPixel(119,210,RED);
	drawPixel(120,210,RED);
	drawPixel(121,210,RED);
	drawPixel(118,210,RED);
	drawPixel(122,210,RED);
	drawPixel(119,211,RED);
	drawPixel(120,211,RED);
	drawPixel(121,211,RED);
	drawPixel(120,212,RED);
	//
	drawPixel(120,203,GREEN);
	//
	drawPixel(120,202,GREEN);
	drawPixel(119,202,GREEN);
	drawPixel(121,202,GREEN);
	//
	drawPixel(120,201,GREEN);
	drawPixel(119,201,GREEN);
	drawPixel(121,201,GREEN);
	drawPixel(118,201,GREEN);
	drawPixel(122,201,GREEN);
	//
	drawPixel(120,200,WHITE);
	drawPixel(120,199,WHITE);
	drawPixel(120,198,WHITE);

	drawPixel(118,206,WHITE);
	drawPixel(116,208,WHITE);
	drawPixel(122,208,WHITE);
	drawPixel(120,210,WHITE);
	drawPixel(124,204,WHITE);
	drawPixel(116,204,WHITE);
	drawPixel(120,205,WHITE);

	while(1)
	{
		//Read raw X, Y positions
		x= readTouchX();
		y=readTouchY();
		yy=y;
		//Read presure
		z=pressure();
		//Convert raw values to X,Y screen positions
		x=map(x,TS_MINX, TS_MAXX, TFTWIDTH, 0);
		y=map(y,TS_MINY, TS_MAXY, TFTHEIGHT, 0);
		//If user touches top of screen, go back to main menu
		if (yy>TS_MAXX+10)
		{
			return;
		}
		else
		{
			//Animate various extra sprites
			if (ani_step==0)
			{
				//Animate pac-mans on top of screen
				fillCircle(45,10,10,YELLOW);
				drawLine(45,10,35,10,BLACK);
				fillCircle(225,10,10,YELLOW);
				drawLine(225,10,235,10,BLACK);
				//Top Middle Ghost eyes
				fillCircle(116,79,2,WHITE);
				fillCircle(124,79,2,WHITE);
				if(pac_x>120 && pac_y>80)
				{
					fillCircle(117,80,1,BLUE);
					fillCircle(125,80,1,BLUE);
				}
				else if(pac_x>120 && pac_y==80)
				{
					fillCircle(117,79,1,BLUE);
					fillCircle(125,79,1,BLUE);
				}
				else if(pac_x>120 && pac_y<80)
				{
					fillCircle(117,78,1,BLUE);
					fillCircle(125,78,1,BLUE);
				}
				else if(pac_x<120 && pac_y>80)
				{
					fillCircle(115,80,1,BLUE);
					fillCircle(123,80,1,BLUE);
				}
				else if(pac_x<120 && pac_y==80)
				{
					fillCircle(115,79,1,BLUE);
					fillCircle(123,79,1,BLUE);
				}
				else if(pac_x<120 && pac_y<80)
				{
					fillCircle(115,78,1,BLUE);
					fillCircle(123,78,1,BLUE);
				}
				else if(pac_x==120 && pac_y<80)
				{
					fillCircle(116,78,1,BLUE);
					fillCircle(124,78,1,BLUE);
				}
				else if(pac_x==120 && pac_y>80)
				{
					fillCircle(116,80,1,BLUE);
					fillCircle(124,80,1,BLUE);
				}
				//Top Right Ghost eyes
				fillCircle(176,79,2,WHITE);
				fillCircle(184,79,2,WHITE);
				if (pac_x>180 && pac_y>80)
				{
					
					fillCircle(177,80,1,BLUE);
					fillCircle(185,80,1,BLUE);
				}
				else if(pac_x>180 && pac_y==80)
				{
					fillCircle(177,79,1,BLUE);
					fillCircle(185,79,1,BLUE);
				}
				else if(pac_x>180 && pac_y<80)
				{
					fillCircle(177,78,1,BLUE);
					fillCircle(185,78,1,BLUE);
				}
				else if (pac_x<180 && pac_y>80)
				{
					fillCircle(175,80,1,BLUE);
					fillCircle(183,80,1,BLUE);
				}
				else if(pac_x<180 && pac_y==80)
				{
					fillCircle(175,79,1,BLUE);
					fillCircle(183,79,1,BLUE);
				}
				else if(pac_x<180 && pac_y<80)
				{
					fillCircle(175,78,1,BLUE);
					fillCircle(183,78,1,BLUE);
				}
				else if(pac_x==180 && pac_y<80)
				{
					fillCircle(176,78,1,BLUE);
					fillCircle(184,78,1,BLUE);
				}
				else if(pac_x==180 && pac_y>80)
				{
					fillCircle(176,80,1,BLUE);
					fillCircle(184,80,1,BLUE);
				}

				//150 Top ghost eyes
				fillCircle(146,79,2,WHITE);
				fillCircle(154,79,2,WHITE);
				if (pac_x>150 && pac_y>80)
				{
					
					fillCircle(147,80,1,BLUE);
					fillCircle(155,80,1,BLUE);
				}
				else if(pac_x>150 && pac_y==80)
				{
					fillCircle(147,79,1,BLUE);
					fillCircle(155,79,1,BLUE);
				}
				else if(pac_x>150 && pac_y<80)
				{
					fillCircle(147,78,1,BLUE);
					fillCircle(155,78,1,BLUE);
				}
				else if (pac_x<150 && pac_y>80)
				{
					fillCircle(145,80,1,BLUE);
					fillCircle(153,80,1,BLUE);
				}
				else if(pac_x<150 && pac_y==80)
				{
					fillCircle(145,79,1,BLUE);
					fillCircle(153,79,1,BLUE);
				}
				else if(pac_x<150 && pac_y<80)
				{
					fillCircle(145,78,1,BLUE);
					fillCircle(153,78,1,BLUE);
				}
				else if(pac_x==150 && pac_y<80)
				{
					fillCircle(146,78,1,BLUE);
					fillCircle(154,78,1,BLUE);
				}
				else if(pac_x==150 && pac_y>80)
				{
					fillCircle(146,80,1,BLUE);
					fillCircle(154,80,1,BLUE);
				}
				//90 Top ghost eyes 
				fillCircle(86,79,2,WHITE);
				fillCircle(94,79,2,WHITE);
				if (pac_x>90 && pac_y>80)
				{
					
					fillCircle(87,80,1,BLUE);
					fillCircle(95,80,1,BLUE);
				}
				else if(pac_x>90 && pac_y==80)
				{
					fillCircle(87,79,1,BLUE);
					fillCircle(95,79,1,BLUE);
				}
				else if(pac_x>90 && pac_y<80)
				{
					fillCircle(87,78,1,BLUE);
					fillCircle(95,78,1,BLUE);
				}
				else if (pac_x<90 && pac_y>80)
				{
					fillCircle(85,80,1,BLUE);
					fillCircle(93,80,1,BLUE);
				}
				else if(pac_x<90 && pac_y==80)
				{
					fillCircle(95,79,1,BLUE);
					fillCircle(93,79,1,BLUE);
				}
				else if(pac_x<90 && pac_y<80)
				{
					fillCircle(85,78,1,BLUE);
					fillCircle(93,78,1,BLUE);
				}
				else if(pac_x==90 && pac_y<80)
				{
					fillCircle(86,78,1,BLUE);
					fillCircle(94,78,1,BLUE);
				}
				else if(pac_x==90 && pac_y>80)
				{
					fillCircle(86,80,1,BLUE);
					fillCircle(94,80,1,BLUE);
				}
				//60 Top ghost eyes
				fillCircle(56,79,2,WHITE);
				fillCircle(64,79,2,WHITE);
				if (pac_x>60 && pac_y>80)
				{
					
					fillCircle(57,80,1,BLUE);
					fillCircle(65,80,1,BLUE);
				}
				else if(pac_x>60 && pac_y==80)
				{
					fillCircle(57,79,1,BLUE);
					fillCircle(65,79,1,BLUE);
				}
				else if(pac_x>60 && pac_y<80)
				{
					fillCircle(57,78,1,BLUE);
					fillCircle(65,78,1,BLUE);
				}
				else if (pac_x<60 && pac_y>80)
				{
					fillCircle(55,80,1,BLUE);
					fillCircle(63,80,1,BLUE);
				}
				else if(pac_x<60 && pac_y==80)
				{
					fillCircle(55,79,1,BLUE);
					fillCircle(63,79,1,BLUE);
				}
				else if(pac_x<60 && pac_y<80)
				{
					fillCircle(55,78,1,BLUE);
					fillCircle(63,78,1,BLUE);
				}
				else if(pac_x==60 && pac_y<80)
				{
					fillCircle(56,78,1,BLUE);
					fillCircle(64,78,1,BLUE);
				}
				else if(pac_x==60 && pac_y>80)
				{
					fillCircle(56,80,1,BLUE);
					fillCircle(64,80,1,BLUE);
				}
				//Bottom 267
				//Bottom Middle Ghost eyes
				fillCircle(116,266,2,WHITE);
				fillCircle(124,266,2,WHITE);
				if(pac_x>120 && pac_y>267)
				{
					fillCircle(117,267,1,BLUE);
					fillCircle(125,267,1,BLUE);
				}
				else if(pac_x>120 && pac_y==267)
				{
					fillCircle(117,266,1,BLUE);
					fillCircle(125,266,1,BLUE);
				}
				else if(pac_x>120 && pac_y<267)
				{
					fillCircle(117,265,1,BLUE);
					fillCircle(125,265,1,BLUE);
				}
				else if(pac_x<120 && pac_y>267)
				{
					fillCircle(115,267,1,BLUE);
					fillCircle(123,267,1,BLUE);
				}
				else if(pac_x<120 && pac_y==267)
				{
					fillCircle(115,266,1,BLUE);
					fillCircle(123,266,1,BLUE);
				}
				else if(pac_x<120 && pac_y<267)
				{
					fillCircle(115,265,1,BLUE);
					fillCircle(123,265,1,BLUE);
				}
				else if(pac_x==120 && pac_y<267)
				{
					fillCircle(116,265,1,BLUE);
					fillCircle(124,265,1,BLUE);
				}
				else if(pac_x==120 && pac_y>267)
				{
					fillCircle(116,267,1,BLUE);
					fillCircle(124,267,1,BLUE);
				}
				//Bottom Right Ghost eyes
				fillCircle(176,266,2,WHITE);
				fillCircle(184,266,2,WHITE);
				if (pac_x>180 && pac_y>267)
				{
					
					fillCircle(177,267,1,BLUE);
					fillCircle(185,267,1,BLUE);
				}
				else if(pac_x>180 && pac_y==267)
				{
					fillCircle(177,266,1,BLUE);
					fillCircle(185,266,1,BLUE);
				}
				else if(pac_x>180 && pac_y<267)
				{
					fillCircle(177,265,1,BLUE);
					fillCircle(185,265,1,BLUE);
				}
				else if (pac_x<180 && pac_y>267)
				{
					fillCircle(175,267,1,BLUE);
					fillCircle(183,267,1,BLUE);
				}
				else if(pac_x<180 && pac_y==267)
				{
					fillCircle(175,266,1,BLUE);
					fillCircle(183,266,1,BLUE);
				}
				else if(pac_x<180 && pac_y<267)
				{
					fillCircle(175,265,1,BLUE);
					fillCircle(183,265,1,BLUE);
				}
				else if(pac_x==180 && pac_y<267)
				{
					fillCircle(176,265,1,BLUE);
					fillCircle(184,265,1,BLUE);
				}
				else if(pac_x==180 && pac_y>267)
				{
					fillCircle(176,267,1,BLUE);
					fillCircle(184,267,1,BLUE);
				}

				//150 Bottom ghost eyes
				fillCircle(146,266,2,WHITE);
				fillCircle(154,266,2,WHITE);
				if (pac_x>150 && pac_y>267)
				{
					
					fillCircle(147,267,1,BLUE);
					fillCircle(155,267,1,BLUE);
				}
				else if(pac_x>150 && pac_y==267)
				{
					fillCircle(147,266,1,BLUE);
					fillCircle(155,266,1,BLUE);
				}
				else if(pac_x>150 && pac_y<267)
				{
					fillCircle(147,265,1,BLUE);
					fillCircle(155,265,1,BLUE);
				}
				else if (pac_x<150 && pac_y>267)
				{
					fillCircle(145,267,1,BLUE);
					fillCircle(153,267,1,BLUE);
				}
				else if(pac_x<150 && pac_y==267)
				{
					fillCircle(145,266,1,BLUE);
					fillCircle(153,266,1,BLUE);
				}
				else if(pac_x<150 && pac_y<267)
				{
					fillCircle(145,265,1,BLUE);
					fillCircle(153,265,1,BLUE);
				}
				else if(pac_x==150 && pac_y<267)
				{
					fillCircle(146,265,1,BLUE);
					fillCircle(154,265,1,BLUE);
				}
				else if(pac_x==150 && pac_y>267)
				{
					fillCircle(146,267,1,BLUE);
					fillCircle(154,267,1,BLUE);
				}
				//90 Bottom ghost eyes
				fillCircle(86,266,2,WHITE);
				fillCircle(94,266,2,WHITE);
				if (pac_x>90 && pac_y>267)
				{
					
					fillCircle(87,267,1,BLUE);
					fillCircle(95,267,1,BLUE);
				}
				else if(pac_x>90 && pac_y==267)
				{
					fillCircle(87,266,1,BLUE);
					fillCircle(95,266,1,BLUE);
				}
				else if(pac_x>90 && pac_y<267)
				{
					fillCircle(87,265,1,BLUE);
					fillCircle(95,265,1,BLUE);
				}
				else if (pac_x<90 && pac_y>267)
				{
					fillCircle(85,267,1,BLUE);
					fillCircle(93,267,1,BLUE);
				}
				else if(pac_x<90 && pac_y==267)
				{
					fillCircle(95,266,1,BLUE);
					fillCircle(93,266,1,BLUE);
				}
				else if(pac_x<90 && pac_y<267)
				{
					fillCircle(85,265,1,BLUE);
					fillCircle(93,265,1,BLUE);
				}
				else if(pac_x==90 && pac_y<267)
				{
					fillCircle(86,265,1,BLUE);
					fillCircle(94,265,1,BLUE);
				}
				else if(pac_x==90 && pac_y>267)
				{
					fillCircle(86,267,1,BLUE);
					fillCircle(94,267,1,BLUE);
				}
				//60 Bottom ghost eyes
				fillCircle(56,266,2,WHITE);
				fillCircle(64,266,2,WHITE);
				if (pac_x>60 && pac_y>267)
				{
					
					fillCircle(57,267,1,BLUE);
					fillCircle(65,267,1,BLUE);
				}
				else if(pac_x>60 && pac_y==267)
				{
					fillCircle(57,266,1,BLUE);
					fillCircle(65,266,1,BLUE);
				}
				else if(pac_x>60 && pac_y<267)
				{
					fillCircle(57,265,1,BLUE);
					fillCircle(65,265,1,BLUE);
				}
				else if (pac_x<60 && pac_y>267)
				{
					fillCircle(55,267,1,BLUE);
					fillCircle(63,267,1,BLUE);
				}
				else if(pac_x<60 && pac_y==267)
				{
					fillCircle(55,266,1,BLUE);
					fillCircle(63,266,1,BLUE);
				}
				else if(pac_x<60 && pac_y<267)
				{
					fillCircle(55,265,1,BLUE);
					fillCircle(63,265,1,BLUE);
				}
				else if(pac_x==60 && pac_y<267)
				{
					fillCircle(56,265,1,BLUE);
					fillCircle(64,265,1,BLUE);
				}
				else if(pac_x==60 && pac_y>267)
				{
					fillCircle(56,267,1,BLUE);
					fillCircle(64,267,1,BLUE);
				}
				ani_step=1;
			}
			else 
			{
				//Animate top pac-mans
				fillTriangle(45,10,35,5,35,15,BLACK);
				fillTriangle(225,10,235,5,235,15,BLACK);
				ani_step=0;
			}
			//If valid touch is detected
			if (z>250 && z<750)
			{
				//If first touch, record x,y position
				if(control==0)
				{
					old_x=x;
					old_y=y;
					new_x=x;
					new_y=y;
					control=1;
				}
				//If not first touch, update positon
				else
				{
					new_x=x;
					new_y=y;
				}	
			}
			else
			{
				//On release, check x,y position change
				if(control==1)
				{
					diff_x=new_x-old_x;
					diff_y=new_y-old_y;
					//If x position changed more
					if (abs(diff_x) > abs(diff_y))
					{
						//Change direction to right if valid
						if(diff_x>0)
						{
							if((pac_x<225 && (pac_y>300 || pac_y<55)) || (pac_y>170 && pac_y<180) || (pac_x<165 && ((pac_y>110 && pac_y<125) || (pac_y<240 && pac_y>230))))  dir=0;
						}
						//Change direction to left if valid
						else if(diff_x<0)
						{
							if ((pac_x>15 && (pac_y>300 || pac_y<55)) || (pac_y>170 && pac_y<180) || (pac_x>75 && ((pac_y>110 && pac_y<125) || (pac_y<240 && pac_y>230)))) dir=2;
						}
					}
					//If y position is more
					else
					{
						//Change direction to down if valid
						if(diff_y>0)
						{
							if(((pac_y<303 && (pac_x>224 || pac_x<16)) || (((pac_x<80 && pac_x>70) || (pac_x<170 && pac_x>160)) && pac_y<235 && pac_y>100)))  dir=3;
						}
						//Change direction to up if valid
						else if(diff_y<0)
						{
							if (((pac_y>55 && (pac_x>224 || pac_x<16)) || (((pac_x<80 && pac_x>70) || (pac_x<170 && pac_x>160)) && pac_y>115 && pac_y<270))) dir=1;
						}
					}
					control=0;
				}
			}
			//If first animation step
			if(step==0)
			{
				//Update pac-man moving right
				if (dir==0)
				{
					if((pac_x<225 && (pac_y<65 || pac_y>300)) || (pac_y>170 && pac_y<180) || (pac_x<165 && ((pac_y>110 && pac_y<125) || (pac_y<240 && pac_y>230)))) 
					{
						fillLeftHalfCircle(pac_x,pac_y,11,BLACK);
						pac_x+=5;
						if(pac_x>240)
						{
							pac_x=0;
						}
						fillCircle(pac_x,pac_y,10,YELLOW);
						drawLine(pac_x,pac_y,pac_x+10,pac_y,BLACK);
						step=1;
					}
				}
				//Update pac-man moving up
				else if (dir==1)
				{
					if (((pac_y>54 && (pac_x>224 || pac_x<16)) || (((pac_x<80 && pac_x>70) || (pac_x<170 && pac_x>160)) && pac_y>115 && pac_y<270)))
					{
						if(pac_y>300)
						{
							fillRect(pac_x,pac_y,10,11,BLACK);
							pac_y=295;
						}
						fillBottomHalfCircle(pac_x,pac_y,12,BLACK);
						pac_y-=5;
						fillCircle(pac_x,pac_y,10,YELLOW);
						drawLine(pac_x,pac_y,pac_x,pac_y-10,BLACK);
						drawLine(0,319,240,319,BLUE);
						drawLine(0,320,240,320,BLUE);
						drawLine(59,251,181,251,BLUE);
						drawLine(59,252,181,252,BLUE);
						step=1;
					}
				}
				//Update pac-man moving left
				else if (dir==2)
				{
					if ((pac_x>15 && (pac_y<65 || pac_y>300)) || (pac_y>170 && pac_y<180) || (pac_x>75 && ((pac_y>110 && pac_y<125) || (pac_y<240 && pac_y>230))))
					{
						fillRightHalfCircle(pac_x,pac_y,11,BLACK);
						pac_x-=5;
						if(pac_x<0)
						{
							pac_x=240;
						}
						fillCircle(pac_x,pac_y,10,YELLOW);
						drawLine(pac_x,pac_y,pac_x-10,pac_y,BLACK);
						step=1;
					}
				}
				//Update pac-man moving down
				else if (dir==3)
				{
					if (((pac_y<300 && (pac_x>224 || pac_x<16)) || (((pac_x<80 && pac_x>70) || (pac_x<170 && pac_x>160)) && pac_y<235 && pac_y>100)))
					{
						fillTopHalfCircle(pac_x,pac_y,11,BLACK);
						pac_y+=5;
						fillCircle(pac_x,pac_y,10,YELLOW);
						drawLine(pac_x,pac_y,pac_x,pac_y+10,BLACK);
						step=1;
					}
					else if(pac_y>=300 && pac_y<303)
					{
						fillTopHalfCircle(pac_x,pac_y,11,BLACK);
						pac_y+=3;
						fillCircle(pac_x,pac_y,10,YELLOW);
						drawLine(pac_x,pac_y,pac_x,pac_y+10,BLACK);
						step=1;
					}
				}
				
			}
			//If second animation step
			else if (step==1)
			{
				//Update pac-man moving right
				if(dir==0)
				{
					fillTriangle(pac_x,pac_y,pac_x+10,pac_y-5,pac_x+10,pac_y+5,BLACK);
				}
				//Update pac-man moving up
				else if(dir==1)
				{
					fillTriangle(pac_x,pac_y,pac_x-5,pac_y-10,pac_x+5,pac_y-10,BLACK);
				}
				//Update pac-man moving left
				else if (dir==2)
				{
					fillTriangle(pac_x,pac_y,pac_x-10,pac_y-5,pac_x-10,pac_y+5,BLACK);
				}
				//Update pac-man moving down
				else if (dir==3)
				{
					fillTriangle(pac_x,pac_y,pac_x-5,pac_y+10,pac_x+5,pac_y+10,BLACK);
				}
				step=0;
			}
			_delay_ms(100); //Delay to improve animation
		}
	}
}
